from pathlib import Path

import pydantic
import yaml
from pydantic.error_wrappers import ErrorWrapper, ValidationError
from pydantic.parse import Protocol, load_file, load_str_bytes
from pydantic.utils import ROOT_KEY

YAML_CONTENT_TYPES = ["text/yaml", "application/x-yaml"]


class BaseModel(pydantic.BaseModel):
    @classmethod
    def parse_file(
        cls,
        path: str | Path,
        *,
        content_type: str = "text/yaml",
        encoding: str = "utf8",
        proto: Protocol = None,
        allow_pickle: bool = False,
    ):
        if content_type not in YAML_CONTENT_TYPES:
            obj = load_file(
                path,
                proto=proto,
                content_type=content_type,
                encoding=encoding,
                allow_pickle=allow_pickle,
                json_loads=cls.__config__.json_loads,
            )
        else:
            with open(path, encoding=encoding) as f:
                obj = yaml.safe_load(f.read())

        return cls.parse_obj(obj)

    @classmethod
    def parse_raw(
        cls,
        b: str | bytes,
        *,
        content_type: str = "text/yaml",
        encoding: str = "utf8",
        proto: Protocol = None,
        allow_pickle: bool = False,
    ):
        try:
            if content_type not in YAML_CONTENT_TYPES:
                obj = load_str_bytes(
                    b,
                    proto=proto,
                    content_type=content_type,
                    encoding=encoding,
                    allow_pickle=allow_pickle,
                    json_loads=cls.__config__.json_loads,
                )
            else:
                obj = yaml.safe_load(b)
        except (ValueError, TypeError, UnicodeDecodeError) as e:
            raise ValidationError([ErrorWrapper(e, loc=ROOT_KEY)], cls) from e

        return cls.parse_obj(obj)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['azuma', 'azuma.parsers', 'azuma.schemas']

package_data = \
{'': ['*']}

install_requires = \
['lark-parser>=0.12,<1.0',
 'pydantic>=1.8,<2.0',
 'pyyaml>=6.0,<7.0',
 'regex>=2022']

setup_kwargs = {
    'name': 'azuma',
    'version': '0.1.1',
    'description': 'Yet another Sigma library for Python',
    'long_description': '# azuma\n\n[![PyPI version](https://badge.fury.io/py/azuma.svg)](https://badge.fury.io/py/azuma)\n[![Test](https://github.com/ninoseki/azuma/actions/workflows/test.yml/badge.svg)](https://github.com/ninoseki/azuma/actions/workflows/test.yml)\n\nYet another [Sigma](https://github.com/SigmaHQ/sigma) library for Python.\n\nNote: This is a forked version of [CybercentreCanada/pysigma](https://github.com/CybercentreCanada/pysigma). Most of the things in this library come from their hard work.\n\n## Docs\n\n- [Requirements](https://github.com/ninoseki/azuma/wiki/Requirements)\n- [Installation](https://github.com/ninoseki/azuma/wiki/Installation)\n- [Usage](https://github.com/ninoseki/azuma/wiki/Usage)\n- [Known limitations](https://github.com/ninoseki/azuma/wiki/Known-limitations)\n',
    'author': 'Manabu Niseki',
    'author_email': 'manabu.niseki@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/ninoseki/azuma',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
